==> library_architecture_mvvm_modify_python-1.0.0.tar.gz: library_architecture_mvvm_modify_python-1.0.0/named_test_main/temp_cache_test_main.py <==
import asyncio
from library_architecture_mvvm_modify_python import TempCacheService, debug_print

def __listen_stream_from_key_temp_cache_and_callback_parameter_one(object: str) -> None:
    debug_print("Listen: " + object)

def __listen_stream_from_key_temp_cache_and_callback_parameter_one_first(object: str) -> None:
    debug_print("ListenTwo: " + object)

def __listen_stream_from_key_temp_cache_and_callback_parameter_one_second(object: str) -> None:
    debug_print("ListenThree: " + object)

async def main() -> None:
    temp_cache_service = TempCacheService()
    key = "key"
    temp_cache_service.update_where_stream_notification_is_possible_from_key_temp_cache_and_value_parameter_one(key,"One")
    from_key_temp_cache_parameter_temp_cache = temp_cache_service.get_from_key_temp_cache_parameter_temp_cache(key)
    debug_print("GetFromKeyTempCacheParameterTempCache: " + from_key_temp_cache_parameter_temp_cache)
    temp_cache_service.listen_stream_from_key_temp_cache_and_callback_parameter_one(key,__listen_stream_from_key_temp_cache_and_callback_parameter_one)
    await asyncio.sleep(1)
    temp_cache_service.update_where_stream_notification_is_possible_from_key_temp_cache_and_value_parameter_one(key,"Two")
    temp_cache_service.listen_stream_from_key_temp_cache_and_callback_parameter_one(key,__listen_stream_from_key_temp_cache_and_callback_parameter_one_first)
    await asyncio.sleep(1)
    temp_cache_service.update_where_stream_notification_is_possible_from_key_temp_cache_and_value_parameter_one(key,"Three")
    temp_cache_service.listen_stream_from_key_temp_cache_and_callback_parameter_one(key,__listen_stream_from_key_temp_cache_and_callback_parameter_one_second)

loop = asyncio.get_event_loop()
loop.run_until_complete(main())
## EXPECTED OUTPUT:
##
## GetFromKeyTempCacheParameterTempCache: One
## Listen: Two
## Listen: Three
## ListenTwo: Three

==> library_architecture_mvvm_modify_python-1.0.2.tar.gz: library_architecture_mvvm_modify_python-1.0.2/named_test_main/temp_cache_test_main.py <==
import asyncio
from library_architecture_mvvm_modify_python import *

def __listen_stream_from_key_temp_cache_and_callback_parameter_one(object: str) -> None:
    debug_print("Listen: " + object)

def __listen_stream_from_key_temp_cache_and_callback_parameter_one_first(object: str) -> None:
    debug_print("ListenTwo: " + object)

def __listen_stream_from_key_temp_cache_and_callback_parameter_one_second(object: str) -> None:
    debug_print("ListenThree: " + object)

async def main() -> None:
    temp_cache_service = TempCacheService()
    key = "key"
    temp_cache_service.update_where_stream_notification_is_possible_from_key_temp_cache_and_value_parameter_one(key,"One")
    from_key_temp_cache_parameter_temp_cache = temp_cache_service.get_from_key_temp_cache_parameter_temp_cache(key)
    debug_print("FromKeyTempCacheParameterTempCache: " + from_key_temp_cache_parameter_temp_cache)
    temp_cache_service.listen_stream_from_key_temp_cache_and_callback_parameter_one(key,__listen_stream_from_key_temp_cache_and_callback_parameter_one)
    await asyncio.sleep(1)
    temp_cache_service.update_where_stream_notification_is_possible_from_key_temp_cache_and_value_parameter_one(key,"Two")
    temp_cache_service.listen_stream_from_key_temp_cache_and_callback_parameter_one(key,__listen_stream_from_key_temp_cache_and_callback_parameter_one_first)
    await asyncio.sleep(1)
    temp_cache_service.update_where_stream_notification_is_possible_from_key_temp_cache_and_value_parameter_one(key,"Three")
    temp_cache_service.listen_stream_from_key_temp_cache_and_callback_parameter_one(key,__listen_stream_from_key_temp_cache_and_callback_parameter_one_second)

loop = asyncio.get_event_loop()
loop.run_until_complete(main())
## EXPECTED OUTPUT:
##
## FromKeyTempCacheParameterTempCache: One
## Listen: Two
## Listen: Three
## ListenTwo: Three
